%global _privatelibs libtrojita_plugins[.]so.*
%global __provides_exclude ^(%{_privatelibs})$
%global __requires_exclude ^(%{_privatelibs})$

# comment out when not a git snapshot
%define git 20200625

%define rel 1

Name:           trojita
Version:        0.7
Release:        %mkrel %{?git:6.git%git.}%{rel}
Group:          Networking/Mail
License:        GPLv2 or GPLv3
Summary:        Qt IMAP e-mail client
Url:            http://trojita.flaska.net
# for git commit 4317aba9fef12810bf5466f310de5cba830144a9
Source0:        https://sourceforge.net/projects/trojita/files/src/%{name}-%{version}%{?git:-git%git}.tar.xz
BuildRequires:  cmake
BuildRequires:  cmake(Gpgmepp)
BuildRequires:  cmake(KF5Sonnet)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5WebKit)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  qttools5
BuildRequires:  ragel
BuildRequires:  qt5keychain-devel

Requires:       qtbase5-database-plugin-sqlite

%description
Trojita is a fast Qt IMAP e-mail client.

* A pure Qt5 application with no additional dependencies
* Robust IMAP core implemented using Qt's Model-View framework
* Standards compliance is a design goal
* On-demand message list and body part loading
* Offline IMAP support
* Support for bandwidth-saving mode aimed at mobile users with expensive connection
* IMAP over SSH -- in addition to usual SSL/TLS connections, the server could be accessed via SSH
* Safe and robust dealing with HTML mail

%prep
%setup -qn %{name}-%{version}%{?git:-git%git}
%autopatch -p1

%build
%cmake_qt5 \
    -DWITH_QT5=ON \
    -DWITH_TESTS=ON \
    -DWITH_ZLIB=ON \
    -DWITH_RAGEL=ON \
    -DWITH_SHARED_PLUGINS=ON \
    -DWITH_QTKEYCHAIN_PLUGIN=ON \
    -DWITH_SONNET_PLUGIN=ON
%make_build

%install
%make_install -C build

# Add translation lang tags
(cd %{buildroot} && find . -name '*.qm') | %__sed -e 's|^.||' | sed -e \
    's:\(.*/locale/trojita_common_\)\([a-z_A-Z]\+\)\(.*qm$\):%lang(\2) \1\2\3:'\
        >> %{name}.lang

%files -f %{name}.lang
%{_bindir}/%{name}
%{_bindir}/be.contacts
%{_datadir}/applications/org.kde.%{name}.desktop
%{_datadir}/metainfo/org.kde.%{name}.appdata.xml
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_libdir}/libtrojita_plugins.so
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/trojita_plugin_QtKeychainPasswordPlugin.so
%{_libdir}/%{name}/trojita_plugin_Sonnet.so


%changelog
* Thu Feb 04 2021 daviddavid <daviddavid> 0.7-6.git20200625.1.mga7
+ Revision: 1674874
- increase rel to ease upgrade (mga#26859)
- update to latest git snapshot: 0.7-git20200625
  * fixes CVE-2020-15047 (mga#26859)

* Tue Apr 02 2019 umeabot <umeabot> 0.7-5.mga7
+ Revision: 1385136
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 0.7-4.mga7
+ Revision: 1301459
- Mageia 7 Mass Rebuild

* Mon Jun 04 2018 daviddavid <daviddavid> 0.7-3.mga7
+ Revision: 1234430
- add patch to fix build with new Qt5 >= 5.11.0

* Fri Sep 09 2016 daviddavid <daviddavid> 0.7-2.mga6
+ Revision: 1050923
- rebuild for new qt5keychain

* Mon Aug 29 2016 daviddavid <daviddavid> 0.7-1.mga6
+ Revision: 1049419
- new version: 0.7

* Sat Jan 23 2016 daviddavid <daviddavid> 0.6-1.mga6
+ Revision: 926606
- new version: 0.6
- remove merged upstream patch
- update BRs

* Thu Oct 29 2015 daviddavid <daviddavid> 0.5-2.mga6
+ Revision: 896385
- add patch0 to fix build with Qt 5.5

* Sun Jun 21 2015 dglent <dglent> 0.5-1.mga6
+ Revision: 837878
- Version 0.5
- build with Qt5

* Wed Oct 15 2014 umeabot <umeabot> 0.4.1-6.mga5
+ Revision: 741705
- Second Mageia 5 Mass Rebuild

* Sun Oct 05 2014 dglent <dglent> 0.4.1-5.mga5
+ Revision: 736959
- Version git 0ae76814 (2014-08-14)
- Feature to launch minimized
- Feature to set imap idle renewal time
- Drop patch osuse-explicitly-mark-libs-as-STATIC-to-not-allow-cmake-ru
- Return to qt4 build (mga#13969)

* Tue Sep 16 2014 umeabot <umeabot> 0.4.1-4.mga5
+ Revision: 689957
- Mageia 5 Mass Rebuild

* Thu Aug 21 2014 neoclust <neoclust> 0.4.1-3.mga5
+ Revision: 666143
- Requires sqlite plugin for qt5

* Thu Aug 21 2014 neoclust <neoclust> 0.4.1-2.mga5
+ Revision: 666139
- Build with qt5

* Thu Jul 03 2014 dglent <dglent> 0.4.1-1.mga5
+ Revision: 642667
- New version 0.4.1
- Add patch from osuse (fix undefined reference while linking)

* Sat Oct 19 2013 umeabot <umeabot> 0.3.93-2.mga4
+ Revision: 531648
- Mageia 4 Mass Rebuild

* Wed Aug 07 2013 matteo <matteo> 0.3.93-1.mga4
+ Revision: 464466
- new version 0.3.93

* Fri Mar 01 2013 matteo <matteo> 0.3.92-1.mga3
+ Revision: 400884
- new stable version

* Tue Feb 05 2013 matteo <matteo> 0.3.91-1.mga3
+ Revision: 394745
- new version

* Mon Jan 14 2013 umeabot <umeabot> 0.3.90-2.mga3
+ Revision: 384810
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 matteo <matteo> 0.3.90-1.mga3
+ Revision: 340284
- added missing requirement (qt4-linguist)
- new version

* Sat Oct 06 2012 matteo <matteo> 0.3-1.mga3
+ Revision: 303034
- added missing br
- imported package trojita

